#
# spec file for package python3-numpy
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define with_atlas 0

Name:           python3-numpy
Version:        1.9.3
Release:        3.6
Url:            http://www.numpy.org/
Summary:        NumPy array processing for numbers, strings, records and objects
License:        BSD-3-Clause
Group:          Development/Libraries/Python
Source:         https://pypi.python.org/packages/source/n/numpy/numpy-%{version}.tar.gz
# PATCH-FIX-OPENSUSE numpy-buildfix.patch -- openSUSE-specific build fixes
Patch0:         numpy-buildfix.patch
# PATCH-FIX-OPENSUSE numpy-1.9.0-remove-__declspec.patch -- fix for spurious compiler warnings that cause build failure
Patch1:         numpy-1.9.0-remove-__declspec.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  blas-devel
BuildRequires:  fdupes
BuildRequires:  gcc-fortran
BuildRequires:  lapack-devel
BuildRequires:  python3 >= 3.2
BuildRequires:  python3-devel >= 3.2
# Cython needed for mtrand.c regenerating (python3.3)
BuildRequires:  python3-Cython
%if %{with_atlas} == 1
BuildRequires:  libatlas3-devel
%endif

%description
NumPy is a general-purpose array-processing package designed to
efficiently manipulate large multi-dimensional arrays of arbitrary
records without sacrificing too much speed for small multi-dimensional
arrays.  NumPy is built on the Numeric code base and adds features
introduced by numarray as well as an extended C-API and the ability to
create arrays of arbitrary type which also makes NumPy suitable for
interfacing with general-purpose data-base applications.

There are also basic facilities for discrete fourier transform,
basic linear algebra and random number generation.

%package devel
Summary:        Development files for numpy applications
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Requires:       blas-devel
Requires:       gcc-fortran
Requires:       lapack-devel
Requires:       python3-devel >= %{py3_ver}
%if %{with_atlas} == 1
Requires:       libatlas3-devel
%endif

%description devel
This package contains files for developing applications using numpy.

%prep
%setup -q -n numpy-%{version}
%patch0 -p1
%patch1 -p1
# Fix non-executable scripts
sed -i "1d" numpy/{compat/setup,distutils/{conv_template,cpuinfo,exec_command,from_template,setup,system_info},f2py/{__init__,auxfuncs,capi_maps,cb_rules,cfuncs,common_rules,crackfortran,diagnose,f2py2e,f90mod_rules,func2subr,rules,setup,use_rules},ma/setup,matrixlib/setup,setup,testing/{print_coercion_tables,setup}}.py

%build
CFLAGS="%{optflags} -fno-strict-aliasing" python3 setup.py build

%install
python3 setup.py install --root="%{buildroot}" --prefix="%{_prefix}"
rm -rf %{buildroot}%{python3_sitearch}/numpy/{,core,distutils,f2py,fft,lib,linalg,ma,matrixlib,oldnumeric,polynomial,random,testing}/tests # Don't package testsuite
%if 0%{?suse_version}
%fdupes -s %{buildroot}%{_prefix}
%endif

%files
%defattr(-,root,root)
%doc *.txt
%{_bindir}/f2py3
%{python3_sitearch}/numpy/
%{python3_sitearch}/numpy-%{version}-py*.egg-info
%exclude %{python3_sitearch}/numpy/*/*/*.c
%exclude %{python3_sitearch}/numpy/*/*.h
%exclude %{python3_sitearch}/numpy/*/*/*.h
%exclude %{python3_sitearch}/numpy/*/*/*/*.h
%exclude %{python3_sitearch}/numpy/core/lib/libnpymath.a

%files devel
%defattr(-,root,root)
%{python3_sitearch}/numpy/*/*/*.c
%{python3_sitearch}/numpy/*/*.h
%{python3_sitearch}/numpy/*/*/*.h
%{python3_sitearch}/numpy/*/*/*/*.h
%{python3_sitearch}/numpy/core/lib/libnpymath.a

%changelog
* Wed Sep 23 2015 arun@gmx.de
- update to version 1.9.3:
  * #5866: fix error finding Python headers when build_ext --include-dirs is set;
  * #6016: fix np.loadtxt error on Python 3.5 when reading from gzip files;
  * #5555: Replace deprecated options for ifort;
  * #6096: remove /GL for VS2015 in check_long_double_representation;
  * #6141: enable Visual Studio 2015 C99 features;
  * #6171: revert C99 complex for MSVC14.
* Mon Mar  2 2015 toddrme2178@gmail.com
- Update to 1.9.2: Bugfix release
  * #5316: fix too large dtype alignment of strings and complex types
  * #5424: fix ma.median when used on ndarrays
  * #5481: Fix astype for structured array fields of different byte order
  * #5354: fix segfault when clipping complex arrays
  * #5524: allow np.argpartition on non ndarrays
  * #5612: Fixes ndarray.fill to accept full range of uint64
  * #5155: Fix loadtxt with comments=None and a string None data
  * #4476: Masked array view fails if structured dtype has datetime component
  * #5388: Make RandomState.set_state and RandomState.get_state threadsafe
  * #5390: make seed, randint and shuffle threadsafe
  * #5374: Fixed incorrect assert_array_almost_equal_nulp documentation
  * #5393: Add support for ATLAS > 3.9.33.
  * #5313: PyArray_AsCArray caused segfault for 3d arrays
  * #5492: handle out of memory in rfftf
  * #4181: fix a few bugs in the random.pareto docstring
  * #5359: minor changes to linspace docstring
  * #4723: fix a compile issues on AIX
* Thu Nov  6 2014 toddrme2178@gmail.com
- Update to 1.9.1: Bugfix release
  * gh-5184: restore linear edge behaviour of gradient to as it was in < 1.9.
    The second order behaviour is available via the `edge_order` keyword
  * gh-4007: workaround Accelerate sgemv crash on OSX 10.9
  * gh-5100: restore object dtype inference from iterable objects without
    `len()`
  * gh-5163: avoid gcc-4.1.2 (red hat 5) miscompilation causing a crash
  * gh-5138: fix nanmedian on arrays containing inf
  * gh-5203: copy inherited masks in MaskedArray.__array_finalize__
  * gh-2317: genfromtxt did not handle filling_values=0 correctly
  * gh-5067: restore api of npy_PyFile_DupClose in python2
  * gh-5063: cannot convert invalid sequence index to tuple
  * gh-5082: Segmentation fault with argmin() on unicode arrays
  * gh-5095: don't propagate subtypes from np.where
  * gh-5104: np.inner segfaults with SciPy's sparse matrices
  * gh-5136: Import dummy_threading if importing threading fails
  * gh-5148: Make numpy import when run with Python flag '-OO'
  * gh-5147: Einsum double contraction in particular order causes ValueError
  * gh-479: Make f2py work with intent(in out)
  * gh-5170: Make python2 .npy files readable in python3
  * gh-5027: Use 'll' as the default length specifier for long long
  * gh-4896: fix build error with MSVC 2013 caused by C99 complex support
  * gh-4465: Make PyArray_PutTo respect writeable flag
  * gh-5225: fix crash when using arange on datetime without dtype set
  * gh-5231: fix build in c99 mode
* Mon Sep  8 2014 toddrme2178@gmail.com
- Update to 1.9.0
  Highlights
  * Numerous performance improvements in various areas, most
    notably indexing and operations on small arrays are
    significantly faster. Indexing operations now also release the
    GIL.
  * Addition of nanmedian and nanpercentile rounds out the
    nanfunction set.
- Remove upstreamed numpy-double-double-le.patch
- Add numpy-1.9.0-remove-__declspec.patch
  Fixes spurious warnings during build.  These warnings are related
  to a windows-specific function that is not built, so the patch
  just removed the function.
  See:
  http://lists.opensuse.org/opensuse-packaging/2014-09/msg00004.html
- Added patch tag for numpy-buildfix.patch
* Mon Aug 11 2014 toddrme2178@gmail.com
- Update to 1.8.2: Bugfix release
  * gh-4836: partition produces wrong results for multiple selections in equal ranges
  * gh-4656: Make fftpack._raw_fft threadsafe
  * gh-4628: incorrect argument order to _copyto in in np.nanmax, np.nanmin
  * gh-4642: Hold GIL for converting dtypes types with fields
  * gh-4733: fix np.linalg.svd(b, compute_uv=False)
  * gh-4853: avoid unaligned simd load on reductions on i386
  * gh-4722: Fix seg fault converting empty string to object
  * gh-4613: Fix lack of NULL check in array_richcompare
  * gh-4774: avoid unaligned access for strided byteswap
  * gh-650: Prevent division by zero when creating arrays from some buffers
  * gh-4602: ifort has issues with optimization flag O2, use O1
- Switch to pypi download location
- Changed Url to current home page
- Minor spec file cleanups
* Mon Apr 14 2014 arun@gmx.de
- bugfix release 1.8.1
* Fri Dec  6 2013 adrian@suse.de
- apply ppc6le fix from python2 version als here:
  * numpy-double-double-le.patch
* Thu Oct 31 2013 toddrme2178@gmail.com
- Update to 1.8.0
  Highlights:
  * New, no 2to3, Python 2 and Python 3 are supported by a common code base.
  * New, gufuncs for linear algebra, enabling operations on stacked arrays.
  * New, inplace fancy indexing for ufuncs with the ``.at`` method.
  * New, ``partition`` function, partial sorting via selection for fast median.
  * New, ``nanmean``, ``nanvar``, and ``nanstd`` functions skipping NaNs.
  * New, ``full`` and ``full_like`` functions to create value initialized arrays.
  * New, ``PyUFunc_RegisterLoopForDescr``, better ufunc support for user dtypes.
  * Numerous performance improvements in many areas.
- Add a new flag to easily enable/disable atlas support for if it
  ever gets fixed in the future
- Rebase numpy-buildfix.patch
- Remove upstreamed numpy-doc-postprocess-encoding.patch
* Thu Aug 15 2013 speilicke@suse.com
- Only buildrequire python3-2to3 on 12.2
* Fri May  3 2013 toddrme2178@gmail.com
- Update to 1.7.1
  * Bugfixes
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Tue Feb 19 2013 highwaystar.ru@gmail.com
- update to 1.7.0
  * This release includes several new features as well as numerous
  bug fixes and refactorings
  Highlights:
  - ``where=`` parameter to ufuncs (allows the use of boolean
  arrays to choose where a computation should be done)
  - ``vectorize`` improvements (added 'excluded' and 'cache'
  keyword, general cleanup and bug fixes)
  - ``numpy.random.choice`` (random sample generating function)
  New Features:
  - Reduction UFuncs Generalize axis= Parameter
  - Reduction UFuncs New keepdims= Parameter
  - Datetime support
  - Custom formatter for printing arrays
  - New function numpy.random.choice
  - New function isclose
  - Preliminary multi-dimensional support in the polynomial package
  - Ability to pad rank-n arrays
  - New argument to searchsorted
  - Added experimental support for the AArch64 architecture.
  * For additional details check release notes at
  http://sourceforge.net/projects/numpy/files/NumPy/1.7.0/
- numpy-fd15162.patch and numpy-python33.patch removed, because
  now is is in upstream
* Wed Dec 12 2012 highwaystar.ru@gmail.com
- regenerate mtrand.c with cython, needed for python3.3 compatibility
* Thu Nov 22 2012 toddrme2178@gmail.com
- Removed openSUSE 11.4 spec file workarounds
* Wed Nov 21 2012 idonmez@suse.com
- Add numpy-fd15162.patch which should fix python3-scipy
  See https://github.com/numpy/numpy/commit/fd15162fbff5dd68c548284947d39bb2a2481183
* Tue Nov 13 2012 idonmez@suse.com
- Add numpy-python33.patch to fix compilation with Python 3.3
* Fri Aug 17 2012 toddrme2178@gmail.com
- Disable atlas buildrequires until the problems with atlas are
  worked out
* Mon Jun  4 2012 toddrme2178@gmail.com
- Add libatlas2 buildrequires
* Fri Jun  1 2012 toddrme2178@gmail.com
- Remove blas/lapack tests since these build successfully on all
  targets now
- Add documentation packages
  These are separate packages because a lot of packages depend on
  numpy, so building the documentation inside the base spec file
  would slow down the build process for the entire project
* Mon May 21 2012 toddrme2178@gmail.com
- Update to version 1.6.2:
  * bugfixes
* Fri May 18 2012 toddrme2178@gmail.com
- Fix rpmlint warnings
* Mon Apr 30 2012 toddrme2178@gmail.com
- Removed tests for unsupported openSUSE versions
* Mon Apr 23 2012 toddrme2178@gmail.com
- Add python 3 package
- devel package BuildRequires -> Requires
